| Title: | Spatial Transcriptomics Iterative Hierarchical Clustering |
|---|---|
| Description: | Spatial transcriptomics iterative hierarchical clustering ('stIHC'), is a method for identifying spatial gene co-expression modules, defined as groups of genes with shared spatial expression patterns. The method is applicable across spatial transcriptomics technologies with differing spatial resolution, and provides a framework for investigating the spatial organisation of gene expression in tissues. For further details, see Higgins C., Li J.J., Carey M. <doi:10.1002/qub2.70011>. |
| Authors: | Catherine Higgins [aut, cre], Jingyi Jessica Li [aut], Michelle Carey [aut] |
| Maintainer: | Catherine Higgins <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 08:27:14 UTC |
| Source: | https://github.com/cran/stIHC |
Spatial Transcriptomics Iterative Hierarchical Clustering
stIHC(data)stIHC(data)
data |
data frame with columns |
A list with elements:
label |
Vector of cluster labels. |
mean_clusters_mat |
Matrix of cluster means. |
clusters |
List of matrices, each matrix contains the observations belonging to that cluster. |
## Load example data within the package rds_path <- system.file("extdata", "spatial_data.rds", package = "stIHC") example_data <- readRDS(rds_path) ## Run stIHC stihc = stIHC(example_data) ## Inspect cluster assignments table(stihc$label)## Load example data within the package rds_path <- system.file("extdata", "spatial_data.rds", package = "stIHC") example_data <- readRDS(rds_path) ## Run stIHC stihc = stIHC(example_data) ## Inspect cluster assignments table(stihc$label)