Welcome to ClientVPS Mirrors

Help for package stIHC
Type: Package
Title: Spatial Transcriptomics Iterative Hierarchical Clustering
Version: 0.1.0
Description: Spatial transcriptomics iterative hierarchical clustering ('stIHC'), is a method for identifying spatial gene co-expression modules, defined as groups of genes with shared spatial expression patterns. The method is applicable across spatial transcriptomics technologies with differing spatial resolution, and provides a framework for investigating the spatial organisation of gene expression in tissues. For further details, see Higgins C., Li J.J., Carey M. <doi:10.1002/qub2.70011>.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (≥ 4.0.0)
Imports: fdaPDE, stats, cluster, mclust
Suggests: testthat (≥ 3.0.0), knitr, rmarkdown, covr
RoxygenNote: 7.3.3
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-08 13:37:37 UTC; crtuser
Author: Catherine Higgins [aut, cre], Jingyi Jessica Li [aut], Michelle Carey [aut]
Maintainer: Catherine Higgins <catherine.higgins@ucd.ie>
Repository: CRAN
Date/Publication: 2026-01-12 18:50:10 UTC

Spatial Transcriptomics Iterative Hierarchical Clustering

Description

Spatial Transcriptomics Iterative Hierarchical Clustering

Usage

stIHC(data)

Arguments

data

data frame with columns x, y for spatial coordinates and subsequent columns containing observations.

Value

A list with elements:

label

Vector of cluster labels.

mean_clusters_mat

Matrix of cluster means.

clusters

List of matrices, each matrix contains the observations belonging to that cluster.

Examples


## Load example data within the package
rds_path <- system.file("extdata", "spatial_data.rds", package = "stIHC")
example_data <- readRDS(rds_path)

## Run stIHC
stihc = stIHC(example_data)

## Inspect cluster assignments
table(stihc$label)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.